@@ -119,10 +119,8 @@ class GSCNodeFunctionCaller:
 
     def emitFunction(self, sio, target, msg):
         msg["cnodefunction"] = target
-
         encoded = msgpack.packb(msg, use_bin_type=True)
-
-        sio.emit("oncnodefunction", {"target": target, "data": encoded})
+        sio.emit(target, encoded)
 
     def sendcnodefunction(self, target, msg):
         time.sleep(self.gsdbs.credentials["cnodesendsleep"])
